pype32.pype32

Package pype32 :: Module pype32 |
[hide private]
[frames] | no frames]

# Module pype32

source code

Common PE structures.

Classes | [hide private]
Main class
| PE PE object.
PE fields
| DosHeader DosHeader object.
| NtHeaders NtHeaders object.
| FileHeader FileHeader object.
| OptionalHeader OptionalHeader object.
| OptionalHeader64 OptionalHeader64 object.
| SectionHeader SectionHeader object.
| SectionHeaders SectionHeaders object.
| Sections Sections object.

Variables | [hide private]
| __revision__ = ``'``$Id$``'``
| __package__ = ``'``pype32``'``